IF OBJECT_ID('[Servers_Extended]') IS NOT NULL DROP VIEW [Servers_Extended]
GO

CREATE VIEW [Servers_Extended]
AS

    SELECT S.*,
           [ServerConfiguration_Status_Code] = CASE
              WHEN EXISTS (SELECT * FROM [ServerConfigurations] _SC 
                            WHERE _SC.[Server_Id] = S.[Server_Id] 
                              AND [ServerConfiguration_Status_Code] = 'D') THEN 'D' 
              WHEN EXISTS(SELECT * FROM [ServerConfigurations] _SC 
                            WHERE _SC.[Server_Id] = S.[Server_Id]) THEN 'C'
              ELSE 'U' END,
           
          [AllDriftPendingRemediation_Indicator] =  CASE 
             WHEN EXISTS(SELECT * FROM [ServerConfigurations] _SC 
                                 WHERE _SC.[Server_Id] = S.[Server_Id]
                            AND [ServerConfiguration_Status_Code] = 'D') 
                  AND 
                  NOT EXISTS(SELECT * FROM [ServerConfigurations] _SC 
                                 WHERE _SC.[Server_Id] = S.[Server_Id] 
                            AND [ServerConfiguration_Status_Code] = 'D'
                            AND [RemediatedWith_Job_Id] IS NULL) THEN 'Y'
             ELSE 'N' END,
          
          [FinalRemediation_Job_Start_Date] = J_FINAL.[Start_Date],
          [FinalRemediation_Job_Id] = J_FINAL.[Job_Id],

          R.[Raft_Name],

          [Latest_CollectionRun_Start_Date] = E_LATEST.[Start_Date],
          [Latest_CollectionRun_Execution_Id] = E_LATEST.[Execution_Id],
          [Latest_CollectionRun_Execution_Status] = E_LATEST.[ExecutionStatus_Code],
          [Latest_CollectionRun_Execution_RunState] = E_LATEST.[ExecutionRunState_Code]

      FROM [Servers] S
 
OUTER APPLY ( 
        SELECT TOP 1 E.*
          FROM [Executions] E
         WHERE (E.[Server_Id] = S.[Server_Id]
            OR (E.[Job_Id] IS NOT NULL
                AND S.[Server_Id] IN(SELECT JS.[Server_Id]
                                       FROM [JobServers] JS
                                      WHERE JS.[Job_Id] = E.[Job_Id]
                                      UNION ALL
                                     SELECT SRS.[Server_Id]
                                       FROM [ServerRoleServers] SRS
                                      INNER JOIN [JobServerRoles] JSR
                                              ON JSR.[ServerRole_Id] = SRS.[ServerRole_Id]
                                      WHERE JSR.[Job_Id] = E.[Job_Id])))
           AND E.[ExecutionMode_Code] IN ('C', 'E')
      ORDER BY E.[Execution_Id] DESC
     ) E_LATEST

OUTER APPLY (
    SELECT TOP 1 J.* 
      FROM [ServerConfigurations] SC 
     INNER JOIN [Jobs] J ON J.[Job_Id] = SC.[RemediatedWith_Job_Id]
     WHERE SC.[Server_Id] = S.[Server_Id] 
       AND [ServerConfiguration_Status_Code] = 'D'
     ORDER BY J.[Start_Date] DESC
) J_FINAL

  LEFT JOIN [Rafts] R
         ON R.[Raft_Id] = S.[Raft_Id]


GO
