EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Credentials_CreateOrUpdateCredential',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Credential_Id',
    /* Description_Text        */ 'Creates a new credential or updates an existing one.'
GO

IF OBJECT_ID('[Credentials_CreateOrUpdateCredential]') IS NOT NULL DROP PROCEDURE [Credentials_CreateOrUpdateCredential]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Credentials_CreateOrUpdateCredential]
(
	@Credential_Name NVARCHAR(50),
    @Environment_Id INT,
    @CredentialType_Name VARCHAR(50),
    @Configuration_Xml XML,
    @AllowFunctionAccess_Indicator YNINDICATOR,
    @Credential_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF (@Credential_Id IS NULL)
	BEGIN
		INSERT INTO [Credentials] 
		(
            [Environment_Id],
            [Credential_Name],
            [CredentialType_Name],
            [Configuration_Xml],
            [AllowFunctionAccess_Indicator]
		)
		VALUES
		(
			@Environment_Id,
            @Credential_Name,
            @CredentialType_Name,
            @Configuration_Xml,
            COALESCE(@AllowFunctionAccess_Indicator, 'N')
		)
		SET @Credential_Id = SCOPE_IDENTITY()

		-- EXEC [Events_RaiseEvent] 'ENVNWS', NULL, @Server_Id
	END
	ELSE
	BEGIN

		UPDATE [Credentials]
		   SET [Environment_Id] = @Environment_Id,
			   [Credential_Name] = @Credential_Name,
               [CredentialType_Name] = @CredentialType_Name,
			   [LegacyConfiguration_Bytes] = NULL,
               [Configuration_Xml] = @Configuration_Xml,
               [AllowFunctionAccess_Indicator] = COALESCE(@AllowFunctionAccess_Indicator, [AllowFunctionAccess_Indicator])
         WHERE [Credential_Id] = @Credential_Id

		--EXEC [Events_RaiseEvent] 'ENVMDS', NULL, @Server_Id
	END


	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Credentials_CreateOrUpdateCredential] TO [OtterUser_Role]
