EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Rafts_RecordDiscoveredItems',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Records discovered raft item metadata.'
GO

IF OBJECT_ID('[Rafts_RecordDiscoveredItems]') IS NOT NULL DROP PROCEDURE [Rafts_RecordDiscoveredItems]
GO

SET QUOTED_IDENTIFIER ON
GO

IF TYPE_ID('DiscoveredRaftItemEntry') IS NOT NULL DROP TYPE DiscoveredRaftItemEntry

CREATE TYPE DiscoveredRaftItemEntry AS TABLE
(
	[Raft_Id] INT NOT NULL,
	[RaftItemType_Code] INT NOT NULL,
	[RaftItem_Name] VARCHAR(200) NOT NULL,
	[DisplayName_Text] NVARCHAR(200) NULL,
	[Description_Text] NVARCHAR(MAX) NULL
)
GO

GRANT EXECUTE ON TYPE::[DiscoveredRaftItemEntry] TO [OtterUser_Role]
GO

CREATE PROCEDURE [Rafts_RecordDiscoveredItems]
(
	@DiscoveredRaftItemEntry_Table dbo.DiscoveredRaftItemEntry READONLY
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
    BEGIN TRANSACTION

	MERGE [DiscoveredRaftItems] AS TARGET
	USING @DiscoveredRaftItemEntry_Table AS SOURCE
	   ON (
	           TARGET.[Raft_Id] = SOURCE.[Raft_Id]
	       AND TARGET.[RaftItemType_Code] = SOURCE.[RaftItemType_Code]
		   AND TARGET.[RaftItem_Name] = SOURCE.[RaftItem_Name]
		  )

	 WHEN MATCHED THEN
		UPDATE SET TARGET.[DisplayName_Text] = SOURCE.[DisplayName_Text],
                   TARGET.[Description_Text] = SOURCE.[Description_Text]

	 WHEN NOT MATCHED BY TARGET THEN
		INSERT ([Raft_Id], [RaftItemType_Code], [RaftItem_Name], [DisplayName_Text], [Description_Text])
		VALUES (SOURCE.[Raft_Id], SOURCE.[RaftItemType_Code], SOURCE.[RaftItem_Name], SOURCE.[DisplayName_Text], SOURCE.[Description_Text])

	 WHEN NOT MATCHED BY SOURCE THEN
		DELETE;

    COMMIT
END TRY BEGIN CATCH
    IF XACT_STATE()<>0 ROLLBACK
    EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Rafts_RecordDiscoveredItems] TO [OtterUser_Role]
