EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Schedules_CreateOrUpdateSchedule',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Schedule_Id',
    /* Description_Text        */ 'Creates a new schedule, or updates an existing one.'
GO


IF OBJECT_ID('[Schedules_CreateOrUpdateSchedule]') IS NOT NULL DROP PROCEDURE [Schedules_CreateOrUpdateSchedule]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Schedules_CreateOrUpdateSchedule]
(
    @Schedule_Name NVARCHAR(50),
    @Schedule_Configuration XML,
	@Active_Indicator YNINDICATOR,
    @Schedule_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION
    
    IF @Schedule_Id IS NULL
    BEGIN

	    INSERT INTO [Schedules]
        (
            [Schedule_Name],
            [Schedule_Configuration],
            [Active_Indicator]
        )
        VALUES
        (   
            @Schedule_Name,
            @Schedule_Configuration,
            @Active_Indicator
        )

        SET @Schedule_Id = SCOPE_IDENTITY()   

    END
    ELSE
    BEGIN

        UPDATE [Schedules]
           SET [Schedule_Name] = COALESCE(@Schedule_Name, [Schedule_Name]),
               [Schedule_Configuration] = COALESCE(@Schedule_Configuration, [Schedule_Configuration]),
               [Active_Indicator] = COALESCE(@Active_Indicator, [Active_Indicator])
         WHERE [Schedule_Id] = @Schedule_Id

    END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Schedules_CreateOrUpdateSchedule] TO [OtterUser_Role]
